==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkDirectory.java <==
// java wrapper for vtkDirectory object
//

package vtk;
import vtk.*;

public class vtkDirectory extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Open_2(String id0);
  public int Open(String id0)
    { return Open_2(id0); }

  private native int GetNumberOfFiles_3();
  public int GetNumberOfFiles()
    { return GetNumberOfFiles_3(); }

  private native String GetFile_4(int id0);
  public String GetFile(int id0)
    { return GetFile_4(id0); }

  private native int FileIsDirectory_5(String id0);
  public int FileIsDirectory(String id0)
    { return FileIsDirectory_5(id0); }

  private native long GetFiles_6();
  public vtkStringArray GetFiles() {
    long temp = GetFiles_6();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetCurrentWorkingDirectory_7(String id0,int id1);
  public String GetCurrentWorkingDirectory(String id0,int id1)
    { return GetCurrentWorkingDirectory_7(id0,id1); }

  private native int MakeDirectory_8(String id0);
  public int MakeDirectory(String id0)
    { return MakeDirectory_8(id0); }

  private native int DeleteDirectory_9(String id0);
  public int DeleteDirectory(String id0)
    { return DeleteDirectory_9(id0); }

  private native int Rename_10(String id0,String id1);
  public int Rename(String id0,String id1)
    { return Rename_10(id0,id1); }

  public vtkDirectory() { super(); }

  public vtkDirectory(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkDirectory.java <==
// java wrapper for vtkDirectory object
//

package vtk;
import vtk.*;

public class vtkDirectory extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Open_2(String id0);
  public int Open(String id0)
    { return Open_2(id0); }

  private native int GetNumberOfFiles_3();
  public int GetNumberOfFiles()
    { return GetNumberOfFiles_3(); }

  private native String GetFile_4(int id0);
  public String GetFile(int id0)
    { return GetFile_4(id0); }

  private native int FileIsDirectory_5(String id0);
  public int FileIsDirectory(String id0)
    { return FileIsDirectory_5(id0); }

  private native long GetFiles_6();
  public vtkStringArray GetFiles() {
    long temp = GetFiles_6();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetCurrentWorkingDirectory_7(String id0,int id1);
  public String GetCurrentWorkingDirectory(String id0,int id1)
    { return GetCurrentWorkingDirectory_7(id0,id1); }

  private native int MakeDirectory_8(String id0);
  public int MakeDirectory(String id0)
    { return MakeDirectory_8(id0); }

  private native int DeleteDirectory_9(String id0);
  public int DeleteDirectory(String id0)
    { return DeleteDirectory_9(id0); }

  private native int Rename_10(String id0,String id1);
  public int Rename(String id0,String id1)
    { return Rename_10(id0,id1); }

  public vtkDirectory() { super(); }

  public vtkDirectory(long id) { super(id); }
  public native long   VTKInit();

}
